<?php

namespace App\Exceptions;

use Exception;
use Illuminate\Validation\ValidationException;
use Illuminate\Auth\Access\AuthorizationException;
use Illuminate\Database\Eloquent\ModelNotFoundException;
use Laravel\Lumen\Exceptions\Handler as ExceptionHandler;
use Symfony\Component\HttpKernel\Exception\HttpException;
use TaGeSo\APIResponse\Response;

class Handler extends ExceptionHandler
{
    /**
     * A list of the exception types that should not be reported.
     *
     * @var array
     */
    protected $dontReport = [
        AuthorizationException::class,
        HttpException::class,
        ModelNotFoundException::class,
        ValidationException::class,
    ];

    /**
     * Report or log an exception.
     *
     * This is a great spot to send exceptions to Sentry, Bugsnag, etc.
     *
     * @param  \Exception  $exception
     * @return void
     */
    public function report(Exception $exception)
    {
        parent::report($exception);
    }

    /**
     * Render an exception into an HTTP response.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \Exception  $exception
     * @return \Illuminate\Http\Response|\Illuminate\Http\JsonResponse
     */
    public function render($request, Exception $exception)
    {
        //Handle Excepions
        try {
            throw $exception;
        } catch (\App\Exceptions\HTTPException $e) {
            $res = new Response();
            $res->setStatus(false);
            $res->setMessage($e->getMessage());
            $res->setStatusCode($e->getHttpStatusCode());
            return $res;
        } catch (ValidationException $e) {
            $res = new Response();
            $res->setStatus(false);
            $res->setMessage($e->getMessage());
            $res->setStatusCode(422);
            $res->withData($e->errors());
            return $res;
        }
        catch (Exception $e) {
            return parent::render($request, $exception);
        }

    }
}
